# Plugin to add flatpak-build command to the Koji CLI
# The code here is partially based on Koji code. Koji license:
#
#    Koji is free software; you can redistribute it and/or
#    modify it under the terms of the GNU Lesser General Public
#    License as published by the Free Software Foundation;
#    version 2.1 of the License.
#
#    This software is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#    Lesser General Public License for more details.
#
#    You should have received a copy of the GNU Lesser General Public
#    License along with this software; if not, write to the Free Software
#    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
#
# Plugin author:
#       Owen Taylor <otaylor@redhat.com

from optparse import OptionParser
from textwrap import dedent

from koji import parse_arches

from koji.plugin import export_cli
from koji_cli.lib import (
    _running_in_bg,
    activate_session,
    watch_tasks,
)


@export_cli
def handle_flatpak_build(goptions, session, args):
    "[build] Build a Flatpak"

    usage = dedent("""\
        usage: %prog flatpak-build [options] <target> <scm_url>
        (Specify the --help global option for a list of other help options)"
    """)

    parser = OptionParser(usage=usage)
    parser.add_option("--arch-override", help="Override build arches")
    parser.add_option("--nowait", action="store_false", dest="wait", help="Don't wait on build")
    parser.add_option("--scratch", action="store_true", default=False,
                      help="Perform a scratch build")
    parser.add_option("--skip-tag", action="store_true", help="Do not attempt to tag package")
    parser.add_option("--wait", action="store_true",
                      help="Wait on the build, even if running in the background")
    (options, args) = parser.parse_args(args)

    if len(args) != 2:
        parser.error("Incorrect number of arguments")
        assert False  # pragma: no cover
    target, scm = args

    if options.arch_override and not options.scratch:
        parser.error("--arch_override is only allowed for --scratch builds")

    activate_session(session, goptions)

    opts = {}
    if options.arch_override:
        opts['arch_override'] = parse_arches(options.arch_override)

    for key in ('scratch', 'skip_tag'):
        val = getattr(options, key)
        if val is not None:
            opts[key] = val

    task_id = session.flatpakBuild(scm, target, opts)

    if not goptions.quiet:
        print("Created task: %d" % task_id)
        print(f"Task info: {goptions.weburl}/taskinfo?taskID={task_id}")
    if options.wait or (options.wait is None and not _running_in_bg()):
        session.logout()
        return watch_tasks(session, [task_id], quiet=goptions.quiet,
                           poll_interval=goptions.poll_interval, topurl=goptions.topurl)
